@@ -18,24 +18,30 @@
 package main
 
 import (
+	"code.superseriousbusiness.org/gotosocial/cmd/gotosocial/action/testrig"
+	"code.superseriousbusiness.org/gotosocial/internal/config"
+	"codeberg.org/gruf/go-debug"
 	"github.com/spf13/cobra"
-	"github.com/superseriousbusiness/gotosocial/cmd/gotosocial/action/testrig"
 )
 
 func testrigCommands() *cobra.Command {
-	testrigCmd := &cobra.Command{
-		Use:   "testrig",
-		Short: "gotosocial testrig-related tasks",
-	}
+	if debug.DEBUG {
+		testrigCmd := &cobra.Command{
+			Use:   "testrig",
+			Short: "gotosocial testrig-related tasks",
+		}
 
-	testrigStartCmd := &cobra.Command{
-		Use:   "start",
-		Short: "start the gotosocial testrig server",
-		RunE: func(cmd *cobra.Command, args []string) error {
-			return run(cmd.Context(), testrig.Start)
-		},
-	}
+		testrigStartCmd := &cobra.Command{
+			Use:   "start",
+			Short: "start the gotosocial testrig server",
+			RunE: func(cmd *cobra.Command, args []string) error {
+				return run(cmd.Context(), testrig.Start)
+			},
+		}
 
-	testrigCmd.AddCommand(testrigStartCmd)
-	return testrigCmd
+		testrigCmd.AddCommand(testrigStartCmd)
+		config.AddTestrig(testrigCmd)
+		return testrigCmd
+	}
+	return nil
 }
