@@ -67,7 +67,7 @@ func (m *Module) WebfingerGETRequest(c *gin.Context) {
 		return
 	}
 
-	requestedUsername, requestedHost, err := util.ExtractWebfingerParts(resourceQuery)
+	requestedUser, requestedHost, err := util.ExtractWebfingerParts(resourceQuery)
 	if err != nil {
 		err := fmt.Errorf("bad webfinger request with resource query %s: %w", resourceQuery, err)
 		apiutil.ErrorHandler(c, gtserror.NewErrorBadRequest(err, err.Error()), m.processor.InstanceGetV1)
@@ -80,7 +80,7 @@ func (m *Module) WebfingerGETRequest(c *gin.Context) {
 		return
 	}
 
-	resp, errWithCode := m.processor.Fedi().WebfingerGet(c.Request.Context(), requestedUsername)
+	resp, errWithCode := m.processor.Fedi().WebfingerGet(c.Request.Context(), requestedUser)
 	if errWithCode != nil {
 		apiutil.ErrorHandler(c, errWithCode, m.processor.InstanceGetV1)
 		return
