@@ -19,16 +19,19 @@ package cache
 
 import (
 	"crypto/rsa"
+	"regexp"
+	"strings"
 	"time"
 	"unsafe"
 
+	"code.superseriousbusiness.org/gotosocial/internal/ap"
+	apimodel "code.superseriousbusiness.org/gotosocial/internal/api/model"
+	"code.superseriousbusiness.org/gotosocial/internal/config"
+	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
+	"code.superseriousbusiness.org/gotosocial/internal/id"
+	"code.superseriousbusiness.org/gotosocial/internal/util"
 	"codeberg.org/gruf/go-cache/v3/simple"
 	"github.com/DmitriyVTitov/size"
-	"github.com/superseriousbusiness/gotosocial/internal/ap"
-	"github.com/superseriousbusiness/gotosocial/internal/config"
-	"github.com/superseriousbusiness/gotosocial/internal/gtsmodel"
-	"github.com/superseriousbusiness/gotosocial/internal/id"
-	"github.com/superseriousbusiness/gotosocial/internal/util"
 )
 
 const (
@@ -65,6 +68,14 @@ you'll make society more equitable for all if you're not careful! :hammer_sickle
 	// be a serialized string of almost any type, so we pick a
 	// nice serialized key size on the upper end of normal.
 	sizeofResultKey = 2 * sizeofIDStr
+
+	// exampleWebPushAuth is a Base64-encoded 16-byte random auth secret.
+	// This secret is consumed as Base64 by webpush-go.
+	exampleWebPushAuth = "ZVxqlt5fzVgmSz2aqiA2XQ=="
+
+	// exampleWebPushP256dh is a Base64-encoded DH P-256 public key.
+	// This secret is consumed as Base64 by webpush-go.
+	exampleWebPushP256dh = "OrpejO16gV97uBXew/T0I7YoUv/CX8fz0z4g8RrQ+edXJqQPjX3XVSo2P0HhcCpCOR1+Dzj5LFcK9jYNqX7SBg=="
 )
 
 var (
@@ -141,7 +152,7 @@ func calculateCacheMax(keySz, valSz uintptr, ratio float64) int {
 
 	// The inputted memory ratio does not take into account the
 	// total of all ratios, so divide it here to get perc. ratio.
-	totalRatio := ratio / totalOfRatios()
+	totalRatio := ratio / config.GetTotalOfMemRatios()
 
 	// TODO: we should also further weight this ratio depending
 	// on the combined keySz + valSz as a ratio of all available
@@ -163,47 +174,6 @@ func calculateCacheMax(keySz, valSz uintptr, ratio float64) int {
 	return int(fMaxMem / (fKeySz + fValSz + emptyBucketOverhead + float64(cacheElemOverhead)))
 }
 
-// totalOfRatios returns the total of all cache ratios added together.
-func totalOfRatios() float64 {
-	// NOTE: this is not performant calculating
-	// this every damn time (mainly the mutex unlocks
-	// required to access each config var). fortunately
-	// we only do this on init so fuck it :D
-	return 0 +
-		config.GetCacheAccountMemRatio() +
-		config.GetCacheAccountNoteMemRatio() +
-		config.GetCacheApplicationMemRatio() +
-		config.GetCacheBlockMemRatio() +
-		config.GetCacheBlockIDsMemRatio() +
-		config.GetCacheBoostOfIDsMemRatio() +
-		config.GetCacheEmojiMemRatio() +
-		config.GetCacheEmojiCategoryMemRatio() +
-		config.GetCacheFollowMemRatio() +
-		config.GetCacheFollowIDsMemRatio() +
-		config.GetCacheFollowRequestMemRatio() +
-		config.GetCacheFollowRequestIDsMemRatio() +
-		config.GetCacheInReplyToIDsMemRatio() +
-		config.GetCacheInstanceMemRatio() +
-		config.GetCacheListMemRatio() +
-		config.GetCacheListEntryMemRatio() +
-		config.GetCacheMarkerMemRatio() +
-		config.GetCacheMediaMemRatio() +
-		config.GetCacheMentionMemRatio() +
-		config.GetCacheNotificationMemRatio() +
-		config.GetCachePollMemRatio() +
-		config.GetCachePollVoteMemRatio() +
-		config.GetCacheReportMemRatio() +
-		config.GetCacheStatusMemRatio() +
-		config.GetCacheStatusFaveMemRatio() +
-		config.GetCacheStatusFaveIDsMemRatio() +
-		config.GetCacheTagMemRatio() +
-		config.GetCacheThreadMuteMemRatio() +
-		config.GetCacheTombstoneMemRatio() +
-		config.GetCacheUserMemRatio() +
-		config.GetCacheWebfingerMemRatio() +
-		config.GetCacheVisibilityMemRatio()
-}
-
 func sizeofAccount() uintptr {
 	return uintptr(size.Of(&gtsmodel.Account{
 		ID:                      exampleID,
@@ -213,13 +183,12 @@ func sizeofAccount() uintptr {
 		DisplayName:             exampleUsername,
 		Note:                    exampleText,
 		NoteRaw:                 exampleText,
-		Memorial:                func() *bool { ok := false; return &ok }(),
+		MemorializedAt:          exampleTime,
 		CreatedAt:               exampleTime,
 		UpdatedAt:               exampleTime,
 		FetchedAt:               exampleTime,
-		Bot:                     func() *bool { ok := true; return &ok }(),
-		Locked:                  func() *bool { ok := true; return &ok }(),
-		Discoverable:            func() *bool { ok := false; return &ok }(),
+		Locked:                  util.Ptr(true),
+		Discoverable:            util.Ptr(false),
 		URI:                     exampleURI,
 		URL:                     exampleURI,
 		InboxURI:                exampleURI,
@@ -227,7 +196,7 @@ func sizeofAccount() uintptr {
 		FollowersURI:            exampleURI,
 		FollowingURI:            exampleURI,
 		FeaturedCollectionURI:   exampleURI,
-		ActorType:               ap.ActorPerson,
+		ActorType:               gtsmodel.AccountActorTypePerson,
 		PrivateKey:              &rsa.PrivateKey{},
 		PublicKey:               &rsa.PublicKey{},
 		PublicKeyURI:            exampleURI,
@@ -252,7 +221,6 @@ func sizeofAccountSettings() uintptr {
 		AccountID:         exampleID,
 		CreatedAt:         exampleTime,
 		UpdatedAt:         exampleTime,
-		Reason:            exampleText,
 		Privacy:           gtsmodel.VisibilityFollowersOnly,
 		Sensitive:         util.Ptr(true),
 		Language:          "fr",
@@ -263,17 +231,27 @@ func sizeofAccountSettings() uintptr {
 	}))
 }
 
+func sizeofAccountStats() uintptr {
+	return uintptr(size.Of(&gtsmodel.AccountStats{
+		AccountID:           exampleID,
+		FollowersCount:      util.Ptr(100),
+		FollowingCount:      util.Ptr(100),
+		StatusesCount:       util.Ptr(100),
+		StatusesPinnedCount: util.Ptr(100),
+		LastStatusAt:        exampleTime,
+	}))
+}
+
 func sizeofApplication() uintptr {
 	return uintptr(size.Of(&gtsmodel.Application{
-		ID:           exampleID,
-		CreatedAt:    exampleTime,
-		UpdatedAt:    exampleTime,
-		Name:         exampleUsername,
-		Website:      exampleURI,
-		RedirectURI:  exampleURI,
-		ClientID:     exampleID,
-		ClientSecret: exampleID,
-		Scopes:       exampleTextSmall,
+		ID:              exampleID,
+		Name:            exampleUsername,
+		Website:         exampleURI,
+		RedirectURIs:    []string{exampleURI},
+		ClientID:        exampleID,
+		ClientSecret:    exampleID,
+		Scopes:          exampleTextSmall,
+		ManagedByUserID: exampleID,
 	}))
 }
 
@@ -288,6 +266,55 @@ func sizeofBlock() uintptr {
 	}))
 }
 
+func sizeofConversation() uintptr {
+	return uintptr(size.Of(&gtsmodel.Conversation{
+		ID:               exampleID,
+		CreatedAt:        exampleTime,
+		UpdatedAt:        exampleTime,
+		AccountID:        exampleID,
+		OtherAccountIDs:  []string{exampleID, exampleID, exampleID},
+		OtherAccountsKey: strings.Join([]string{exampleID, exampleID, exampleID}, ","),
+		ThreadID:         exampleID,
+		LastStatusID:     exampleID,
+		Read:             util.Ptr(true),
+	}))
+}
+
+func sizeofDomainPermissionDraft() uintptr {
+	return uintptr(size.Of(&gtsmodel.DomainPermissionDraft{
+		ID:                 exampleID,
+		CreatedAt:          exampleTime,
+		UpdatedAt:          exampleTime,
+		PermissionType:     gtsmodel.DomainPermissionBlock,
+		Domain:             "example.org",
+		CreatedByAccountID: exampleID,
+		PrivateComment:     exampleTextSmall,
+		PublicComment:      exampleTextSmall,
+		Obfuscate:          util.Ptr(false),
+		SubscriptionID:     exampleID,
+	}))
+}
+
+func sizeofDomainPermissionSubscription() uintptr {
+	return uintptr(size.Of(&gtsmodel.DomainPermissionSubscription{
+		ID:                    exampleID,
+		Priority:              uint8(255),
+		Title:                 exampleTextSmall,
+		PermissionType:        gtsmodel.DomainPermissionBlock,
+		AsDraft:               util.Ptr(true),
+		CreatedByAccountID:    exampleID,
+		URI:                   exampleURI,
+		ContentType:           gtsmodel.DomainPermSubContentTypeCSV,
+		FetchUsername:         "username",
+		FetchPassword:         "password",
+		FetchedAt:             exampleTime,
+		SuccessfullyFetchedAt: exampleTime,
+		ETag:                  exampleID,
+		LastModified:          exampleTime,
+		Error:                 exampleTextSmall,
+	}))
+}
+
 func sizeofEmoji() uintptr {
 	return uintptr(size.Of(&gtsmodel.Emoji{
 		ID:                     exampleID,
@@ -303,7 +330,6 @@ func sizeofEmoji() uintptr {
 		ImageStaticPath:        exampleURI,
 		ImageContentType:       "image/png",
 		ImageStaticContentType: "image/png",
-		ImageUpdatedAt:         exampleTime,
 		Disabled:               func() *bool { ok := false; return &ok }(),
 		URI:                    "http://localhost:8080/emoji/01F8MH9H8E4VG3KDYJR9EGPXCQ",
 		VisibleInPicker:        func() *bool { ok := true; return &ok }(),
@@ -324,8 +350,6 @@ func sizeofEmojiCategory() uintptr {
 func sizeofFilter() uintptr {
 	return uintptr(size.Of(&gtsmodel.Filter{
 		ID:        exampleID,
-		CreatedAt: exampleTime,
-		UpdatedAt: exampleTime,
 		ExpiresAt: exampleTime,
 		AccountID: exampleID,
 		Title:     exampleTextSmall,
@@ -335,21 +359,18 @@ func sizeofFilter() uintptr {
 
 func sizeofFilterKeyword() uintptr {
 	return uintptr(size.Of(&gtsmodel.FilterKeyword{
-		ID:        exampleID,
-		CreatedAt: exampleTime,
-		UpdatedAt: exampleTime,
-		FilterID:  exampleID,
-		Keyword:   exampleTextSmall,
+		ID:       exampleID,
+		FilterID: exampleID,
+		Keyword:  exampleTextSmall,
+		Regexp:   regexp.MustCompile("^match (this)? .*"),
 	}))
 }
 
 func sizeofFilterStatus() uintptr {
 	return uintptr(size.Of(&gtsmodel.FilterStatus{
-		ID:        exampleID,
-		CreatedAt: exampleTime,
-		UpdatedAt: exampleTime,
-		FilterID:  exampleID,
-		StatusID:  exampleID,
+		ID:       exampleID,
+		FilterID: exampleID,
+		StatusID: exampleID,
 	}))
 }
 
@@ -395,6 +416,21 @@ func sizeofInstance() uintptr {
 	}))
 }
 
+func sizeofInteractionRequest() uintptr {
+	return uintptr(size.Of(&gtsmodel.InteractionRequest{
+		ID:                    exampleID,
+		TargetStatusID:        exampleID,
+		TargetAccountID:       exampleID,
+		InteractingAccountID:  exampleID,
+		InteractionRequestURI: exampleURI,
+		InteractionURI:        exampleURI,
+		InteractionType:       gtsmodel.InteractionAnnounce,
+		AcceptedAt:            exampleTime,
+		ResponseURI:           exampleURI,
+		AuthorizationURI:      exampleURI,
+	}))
+}
+
 func sizeofList() uintptr {
 	return uintptr(size.Of(&gtsmodel.List{
 		ID:            exampleID,
@@ -406,16 +442,6 @@ func sizeofList() uintptr {
 	}))
 }
 
-func sizeofListEntry() uintptr {
-	return uintptr(size.Of(&gtsmodel.ListEntry{
-		ID:        exampleID,
-		CreatedAt: exampleTime,
-		UpdatedAt: exampleTime,
-		ListID:    exampleID,
-		FollowID:  exampleID,
-	}))
-}
-
 func sizeofMarker() uintptr {
 	return uintptr(size.Of(&gtsmodel.Marker{
 		AccountID:  exampleID,
@@ -433,7 +459,6 @@ func sizeofMedia() uintptr {
 		URL:               exampleURI,
 		RemoteURL:         exampleURI,
 		CreatedAt:         exampleTime,
-		UpdatedAt:         exampleTime,
 		Type:              gtsmodel.FileTypeImage,
 		AccountID:         exampleID,
 		Description:       exampleText,
@@ -442,12 +467,10 @@ func sizeofMedia() uintptr {
 		File: gtsmodel.File{
 			Path:        exampleURI,
 			ContentType: "image/jpeg",
-			UpdatedAt:   exampleTime,
 		},
 		Thumbnail: gtsmodel.Thumbnail{
 			Path:        exampleURI,
 			ContentType: "image/jpeg",
-			UpdatedAt:   exampleTime,
 			URL:         exampleURI,
 			RemoteURL:   exampleURI,
 		},
@@ -462,13 +485,10 @@ func sizeofMention() uintptr {
 		ID:               exampleURI,
 		StatusID:         exampleURI,
 		CreatedAt:        exampleTime,
-		UpdatedAt:        exampleTime,
 		OriginAccountID:  exampleURI,
 		OriginAccountURI: exampleURI,
 		TargetAccountID:  exampleID,
-		NameString:       exampleUsername,
-		TargetAccountURI: exampleURI,
-		TargetAccountURL: exampleURI,
+		Silent:           util.Ptr(false),
 	}))
 }
 
@@ -488,11 +508,11 @@ func sizeofMove() uintptr {
 func sizeofNotification() uintptr {
 	return uintptr(size.Of(&gtsmodel.Notification{
 		ID:               exampleID,
-		NotificationType: gtsmodel.NotificationFave,
+		NotificationType: gtsmodel.NotificationFavourite,
 		CreatedAt:        exampleTime,
 		TargetAccountID:  exampleID,
 		OriginAccountID:  exampleID,
-		StatusID:         exampleID,
+		StatusOrEditID:   exampleID,
 		Read:             func() *bool { ok := false; return &ok }(),
 	}))
 }
@@ -535,19 +555,62 @@ func sizeofReport() uintptr {
 	}))
 }
 
+func sizeofScheduledStatus() uintptr {
+	return uintptr(size.Of(&gtsmodel.ScheduledStatus{
+		ID:          exampleID,
+		AccountID:   exampleID,
+		ScheduledAt: exampleTime,
+		Text:        exampleText,
+		Poll: gtsmodel.ScheduledStatusPoll{
+			Options:    []string{exampleTextSmall, exampleTextSmall, exampleTextSmall, exampleTextSmall},
+			Multiple:   util.Ptr(false),
+			HideTotals: util.Ptr(false),
+		},
+		MediaIDs:    []string{exampleID, exampleID, exampleID},
+		Sensitive:   util.Ptr(false),
+		SpoilerText: exampleText,
+		Visibility:  gtsmodel.VisibilityPublic,
+		Language:    "en",
+	}))
+}
+
+func sizeofSinBinStatus() uintptr {
+	return uintptr(size.Of(&gtsmodel.SinBinStatus{
+		ID:                  exampleID,
+		CreatedAt:           exampleTime,
+		UpdatedAt:           exampleTime,
+		URI:                 exampleURI,
+		URL:                 exampleURI,
+		Domain:              exampleURI,
+		AccountURI:          exampleURI,
+		InReplyToURI:        exampleURI,
+		Content:             exampleText,
+		AttachmentLinks:     []string{exampleURI, exampleURI},
+		MentionTargetURIs:   []string{exampleURI},
+		EmojiLinks:          []string{exampleURI},
+		PollOptions:         []string{exampleTextSmall, exampleTextSmall, exampleTextSmall, exampleTextSmall},
+		ContentWarning:      exampleTextSmall,
+		Visibility:          gtsmodel.VisibilityPublic,
+		Sensitive:           util.Ptr(false),
+		Language:            "en",
+		ActivityStreamsType: ap.ObjectNote,
+	}))
+}
+
 func sizeofStatus() uintptr {
 	return uintptr(size.Of(&gtsmodel.Status{
-		ID:                       exampleURI,
+		ID:                       exampleID,
 		URI:                      exampleURI,
 		URL:                      exampleURI,
 		Content:                  exampleText,
 		Text:                     exampleText,
+		ContentType:              gtsmodel.StatusContentTypePlain,
 		AttachmentIDs:            []string{exampleID, exampleID, exampleID},
 		TagIDs:                   []string{exampleID, exampleID, exampleID},
 		MentionIDs:               []string{},
 		EmojiIDs:                 []string{exampleID, exampleID, exampleID},
 		CreatedAt:                exampleTime,
-		UpdatedAt:                exampleTime,
+		EditedAt:                 exampleTime,
 		FetchedAt:                exampleTime,
 		Local:                    func() *bool { ok := false; return &ok }(),
 		AccountURI:               exampleURI,
@@ -558,18 +621,48 @@ func sizeofStatus() uintptr {
 		BoostOfID:                exampleID,
 		BoostOfAccountID:         exampleID,
 		ContentWarning:           exampleUsername, // similar length
+		ContentWarningText:       exampleUsername, // similar length
 		Visibility:               gtsmodel.VisibilityPublic,
 		Sensitive:                func() *bool { ok := false; return &ok }(),
 		Language:                 "en",
 		CreatedWithApplicationID: exampleID,
 		Federated:                func() *bool { ok := true; return &ok }(),
-		Boostable:                func() *bool { ok := true; return &ok }(),
-		Replyable:                func() *bool { ok := true; return &ok }(),
-		Likeable:                 func() *bool { ok := true; return &ok }(),
 		ActivityStreamsType:      ap.ObjectNote,
 	}))
 }
 
+func sizeofStatusBookmark() uintptr {
+	return uintptr(size.Of(&gtsmodel.StatusBookmark{
+		ID:              exampleID,
+		AccountID:       exampleID,
+		Account:         nil,
+		TargetAccountID: exampleID,
+		TargetAccount:   nil,
+		StatusID:        exampleID,
+		Status:          nil,
+		CreatedAt:       exampleTime,
+		UpdatedAt:       exampleTime,
+	}))
+}
+
+func sizeofStatusEdit() uintptr {
+	return uintptr(size.Of(&gtsmodel.StatusEdit{
+		ID:             exampleID,
+		Content:        exampleText,
+		ContentWarning: exampleUsername, // similar length
+		Text:           exampleText,
+		ContentType:    gtsmodel.StatusContentTypePlain,
+		Language:       "en",
+		Sensitive:      func() *bool { ok := false; return &ok }(),
+		AttachmentIDs:  []string{exampleID, exampleID, exampleID},
+		Attachments:    nil,
+		PollOptions:    []string{exampleTextSmall, exampleTextSmall, exampleTextSmall, exampleTextSmall},
+		PollVotes:      []int{69, 420, 1337, 1969},
+		StatusID:       exampleID,
+		CreatedAt:      exampleTime,
+	}))
+}
+
 func sizeofStatusFave() uintptr {
 	return uintptr(size.Of(&gtsmodel.StatusFave{
 		ID:              exampleID,
@@ -581,6 +674,20 @@ func sizeofStatusFave() uintptr {
 	}))
 }
 
+func sizeofStatusFilterResults() uintptr {
+	return uintptr(size.Of(&CachedStatusFilterResults{
+		StatusID:    exampleID,
+		RequesterID: exampleID,
+		Results: [5][]StatusFilterResult{
+			{{Result: &apimodel.FilterResult{KeywordMatches: []string{"key", "word"}}}, {Result: &apimodel.FilterResult{StatusMatches: []string{exampleID, exampleID}}}, {}},
+			{{Result: &apimodel.FilterResult{KeywordMatches: []string{"key", "word"}}}, {Result: &apimodel.FilterResult{StatusMatches: []string{exampleID, exampleID}}}, {}},
+			{{Result: &apimodel.FilterResult{KeywordMatches: []string{"key", "word"}}}, {Result: &apimodel.FilterResult{StatusMatches: []string{exampleID, exampleID}}}, {}},
+			{{Result: &apimodel.FilterResult{KeywordMatches: []string{"key", "word"}}}, {Result: &apimodel.FilterResult{StatusMatches: []string{exampleID, exampleID}}}, {}},
+			{{Result: &apimodel.FilterResult{KeywordMatches: []string{"key", "word"}}}, {Result: &apimodel.FilterResult{StatusMatches: []string{exampleID, exampleID}}}, {}},
+		},
+	}))
+}
+
 func sizeofTag() uintptr {
 	return uintptr(size.Of(&gtsmodel.Tag{
 		ID:        exampleID,
@@ -592,7 +699,7 @@ func sizeofTag() uintptr {
 	}))
 }
 
-func sizeOfThreadMute() uintptr {
+func sizeofThreadMute() uintptr {
 	return uintptr(size.Of(&gtsmodel.ThreadMute{
 		ID:        exampleID,
 		CreatedAt: exampleTime,
@@ -602,6 +709,28 @@ func sizeOfThreadMute() uintptr {
 	}))
 }
 
+func sizeofToken() uintptr {
+	return uintptr(size.Of(&gtsmodel.Token{
+		ID:                  exampleID,
+		LastUsed:            exampleTime,
+		ClientID:            exampleID,
+		UserID:              exampleID,
+		RedirectURI:         exampleURI,
+		Scope:               "r:w",
+		Code:                "", // TODO
+		CodeChallenge:       "", // TODO
+		CodeChallengeMethod: "", // TODO
+		CodeCreateAt:        exampleTime,
+		CodeExpiresAt:       exampleTime,
+		Access:              exampleID + exampleID,
+		AccessCreateAt:      exampleTime,
+		AccessExpiresAt:     exampleTime,
+		Refresh:             "", // TODO: clients don't really support this very well yet
+		RefreshCreateAt:     exampleTime,
+		RefreshExpiresAt:    exampleTime,
+	}))
+}
+
 func sizeofTombstone() uintptr {
 	return uintptr(size.Of(&gtsmodel.Tombstone{
 		ID:        exampleID,
@@ -612,6 +741,18 @@ func sizeofTombstone() uintptr {
 	}))
 }
 
+func sizeofMute() uintptr {
+	return uintptr(size.Of(&CachedMute{
+		StatusID:           exampleID,
+		ThreadID:           exampleID,
+		RequesterID:        exampleID,
+		Mute:               true,
+		MuteExpiry:         exampleTime,
+		Notifications:      true,
+		NotificationExpiry: exampleTime,
+	}))
+}
+
 func sizeofVisibility() uintptr {
 	return uintptr(size.Of(&CachedVisibility{
 		ItemID:      exampleID,
@@ -629,11 +770,8 @@ func sizeofUser() uintptr {
 		Email:                  exampleURI,
 		AccountID:              exampleID,
 		EncryptedPassword:      exampleTextSmall,
-		CurrentSignInAt:        exampleTime,
-		LastSignInAt:           exampleTime,
 		InviteID:               exampleID,
-		ChosenLanguages:        []string{"en", "fr", "jp"},
-		FilteredLanguages:      []string{"en", "fr", "jp"},
+		Reason:                 exampleText,
 		Locale:                 "en",
 		CreatedByApplicationID: exampleID,
 		LastEmailedAt:          exampleTime,
@@ -641,12 +779,32 @@ func sizeofUser() uintptr {
 		ConfirmationSentAt:     exampleTime,
 		ConfirmedAt:            exampleTime,
 		UnconfirmedEmail:       exampleURI,
-		Moderator:              func() *bool { ok := true; return &ok }(),
-		Admin:                  func() *bool { ok := true; return &ok }(),
-		Disabled:               func() *bool { ok := true; return &ok }(),
-		Approved:               func() *bool { ok := true; return &ok }(),
+		Moderator:              util.Ptr(false),
+		Admin:                  util.Ptr(false),
+		Disabled:               util.Ptr(false),
+		Approved:               util.Ptr(false),
 		ResetPasswordToken:     exampleTextSmall,
 		ResetPasswordSentAt:    exampleTime,
 		ExternalID:             exampleID,
 	}))
 }
+
+func sizeofUserMute() uintptr {
+	return uintptr(size.Of(&gtsmodel.UserMute{
+		ID:              exampleID,
+		CreatedAt:       exampleTime,
+		UpdatedAt:       exampleTime,
+		ExpiresAt:       exampleTime,
+		AccountID:       exampleID,
+		TargetAccountID: exampleID,
+		Notifications:   util.Ptr(false),
+	}))
+}
+
+func sizeofWebPushSubscription() uintptr {
+	return uintptr(size.Of(&gtsmodel.WebPushSubscription{
+		TokenID: exampleID,
+		Auth:    exampleWebPushAuth,
+		P256dh:  exampleWebPushP256dh,
+	}))
+}
