@@ -18,24 +18,24 @@
 package dereferencing
 
 import (
+	"cmp"
 	"context"
 	"errors"
-	"io"
 	"net/url"
 	"time"
 
-	"github.com/superseriousbusiness/activity/pub"
-	"github.com/superseriousbusiness/gotosocial/internal/ap"
-	"github.com/superseriousbusiness/gotosocial/internal/config"
-	"github.com/superseriousbusiness/gotosocial/internal/db"
-	"github.com/superseriousbusiness/gotosocial/internal/gtscontext"
-	"github.com/superseriousbusiness/gotosocial/internal/gtserror"
-	"github.com/superseriousbusiness/gotosocial/internal/gtsmodel"
-	"github.com/superseriousbusiness/gotosocial/internal/id"
-	"github.com/superseriousbusiness/gotosocial/internal/log"
-	"github.com/superseriousbusiness/gotosocial/internal/media"
-	"github.com/superseriousbusiness/gotosocial/internal/transport"
-	"github.com/superseriousbusiness/gotosocial/internal/util"
+	"code.superseriousbusiness.org/activity/pub"
+	"code.superseriousbusiness.org/gotosocial/internal/ap"
+	"code.superseriousbusiness.org/gotosocial/internal/config"
+	"code.superseriousbusiness.org/gotosocial/internal/db"
+	"code.superseriousbusiness.org/gotosocial/internal/gtscontext"
+	"code.superseriousbusiness.org/gotosocial/internal/gtserror"
+	"code.superseriousbusiness.org/gotosocial/internal/gtsmodel"
+	"code.superseriousbusiness.org/gotosocial/internal/id"
+	"code.superseriousbusiness.org/gotosocial/internal/log"
+	"code.superseriousbusiness.org/gotosocial/internal/media"
+	"code.superseriousbusiness.org/gotosocial/internal/util"
+	errorsv2 "codeberg.org/gruf/go-errors/v2"
 )
 
 // accountFresh returns true if the given account is
@@ -89,33 +89,60 @@ func accountFresh(
 	return !time.Now().After(staleAt)
 }
 
-// GetAccountByURI will attempt to fetch an accounts by its URI, first checking the database. In the case of a newly-met remote model, or a remote model
-// whose last_fetched date is beyond a certain interval, the account will be dereferenced. In the case of dereferencing, some low-priority account information
-// may be enqueued for asynchronous fetching, e.g. featured account statuses (pins). An ActivityPub object indicates the account was dereferenced.
-func (d *Dereferencer) GetAccountByURI(ctx context.Context, requestUser string, uri *url.URL) (*gtsmodel.Account, ap.Accountable, error) {
+// GetAccountByURI will attempt to fetch an accounts by its
+// URI, first checking the database. In the case of a newly-met
+// remote model, or a remote model whose last_fetched date is
+// beyond a certain interval, the account will be dereferenced.
+// In the case of dereferencing, some low-priority account info
+// may be enqueued for asynchronous fetching, e.g. pinned statuses.
+// An ActivityPub object indicates the account was dereferenced.
+//
+// if tryURL is true, then the database will also check for a *single*
+// account where uri == account.url, not just uri == account.uri.
+// Because url does not guarantee uniqueness, you should only set
+// tryURL to true when doing searches set in motion by a user,
+// ie., when it's not important that an exact account is returned.
+func (d *Dereferencer) GetAccountByURI(
+	ctx context.Context,
+	requestUser string,
+	uri *url.URL,
+	tryURL bool,
+) (*gtsmodel.Account, ap.Accountable, error) {
 	// Fetch and dereference account if necessary.
 	account, accountable, err := d.getAccountByURI(ctx,
 		requestUser,
 		uri,
+		tryURL,
 	)
 	if err != nil {
 		return nil, nil, err
 	}
 
 	if accountable != nil {
-		// This account was updated, enqueue re-dereference featured posts.
-		d.state.Workers.Federator.MustEnqueueCtx(ctx, func(ctx context.Context) {
+		// This account was updated, enqueue re-dereference featured posts + stats.
+		d.state.Workers.Dereference.Queue.Push(func(ctx context.Context) {
 			if err := d.dereferenceAccountFeatured(ctx, requestUser, account); err != nil {
 				log.Errorf(ctx, "error fetching account featured collection: %v", err)
 			}
+
+			if err := d.dereferenceAccountStats(ctx, requestUser, account); err != nil {
+				log.Errorf(ctx, "error fetching account stats: %v", err)
+			}
 		})
 	}
 
 	return account, accountable, nil
 }
 
-// getAccountByURI is a package internal form of .GetAccountByURI() that doesn't bother dereferencing featured posts on update.
-func (d *Dereferencer) getAccountByURI(ctx context.Context, requestUser string, uri *url.URL) (*gtsmodel.Account, ap.Accountable, error) {
+// getAccountByURI is a package internal form of
+// .GetAccountByURI() that doesn't bother dereferencing
+// featured posts on update.
+func (d *Dereferencer) getAccountByURI(
+	ctx context.Context,
+	requestUser string,
+	uri *url.URL,
+	tryURL bool,
+) (*gtsmodel.Account, ap.Accountable, error) {
 	var (
 		account *gtsmodel.Account
 		uriStr  = uri.String()
@@ -123,9 +150,8 @@ func (d *Dereferencer) getAccountByURI(ctx context.Context, requestUser string,
 	)
 
 	// Search the database for existing account with URI.
+	// URI is unique so if we get a hit it's that account for sure.
 	account, err = d.state.DB.GetAccountByURI(
-		// request a barebones object, it may be in the
-		// db but with related models not yet dereferenced.
 		gtscontext.SetBarebones(ctx),
 		uriStr,
 	)
@@ -133,13 +159,20 @@ func (d *Dereferencer) getAccountByURI(ctx context.Context, requestUser string,
 		return nil, nil, gtserror.Newf("error checking database for account %s by uri: %w", uriStr, err)
 	}
 
-	if account == nil {
-		// Else, search the database for existing by URL.
-		account, err = d.state.DB.GetAccountByURL(
+	if account == nil && tryURL {
+		// Else if we're permitted, search the database for *ONE*
+		// account with this URL. This can return multiple hits
+		// so check for ErrMultipleEntries. If we get exactly one
+		// hit it's *probably* the account we're looking for.
+		account, err = d.state.DB.GetOneAccountByURL(
 			gtscontext.SetBarebones(ctx),
 			uriStr,
 		)
-		if err != nil && !errors.Is(err, db.ErrNoEntries) {
+		if err != nil && !errorsv2.IsV2(
+			err,
+			db.ErrNoEntries,
+			db.ErrMultipleEntries,
+		) {
 			return nil, nil, gtserror.Newf("error checking database for account %s by url: %w", uriStr, err)
 		}
 	}
@@ -151,11 +184,22 @@ func (d *Dereferencer) getAccountByURI(ctx context.Context, requestUser string,
 		}
 
 		// Create and pass-through a new bare-bones model for dereferencing.
-		return d.enrichAccountSafely(ctx, requestUser, uri, &gtsmodel.Account{
+		account, accountable, err := d.enrichAccountSafely(ctx, requestUser, uri, &gtsmodel.Account{
 			ID:     id.NewULID(),
 			Domain: uri.Host,
 			URI:    uriStr,
 		}, nil)
+		if err != nil {
+			return nil, nil, err
+		}
+
+		// We have a new account. Ensure basic account stats populated;
+		// real stats will be fetched from remote asynchronously.
+		if err := d.state.DB.StubAccountStats(ctx, account); err != nil {
+			return nil, nil, gtserror.Newf("error stubbing account stats: %w", err)
+		}
+
+		return account, accountable, nil
 	}
 
 	if accountFresh(account, nil) {
@@ -200,11 +244,15 @@ func (d *Dereferencer) GetAccountByUsernameDomain(ctx context.Context, requestUs
 	}
 
 	if accountable != nil {
-		// This account was updated, enqueue re-dereference featured posts.
-		d.state.Workers.Federator.MustEnqueueCtx(ctx, func(ctx context.Context) {
+		// This account was updated, enqueue re-dereference featured posts + stats.
+		d.state.Workers.Dereference.Queue.Push(func(ctx context.Context) {
 			if err := d.dereferenceAccountFeatured(ctx, requestUser, account); err != nil {
 				log.Errorf(ctx, "error fetching account featured collection: %v", err)
 			}
+
+			if err := d.dereferenceAccountStats(ctx, requestUser, account); err != nil {
+				log.Errorf(ctx, "error fetching account stats: %v", err)
+			}
 		})
 	}
 
@@ -252,6 +300,12 @@ func (d *Dereferencer) getAccountByUsernameDomain(
 			return nil, nil, err
 		}
 
+		// We have a new account. Ensure basic account stats populated;
+		// real stats will be fetched from remote asynchronously.
+		if err := d.state.DB.StubAccountStats(ctx, account); err != nil {
+			return nil, nil, gtserror.Newf("error stubbing account stats: %w", err)
+		}
+
 		return account, accountable, nil
 	}
 
@@ -317,15 +371,19 @@ func (d *Dereferencer) RefreshAccount(
 	)
 	if err != nil {
 		log.Errorf(ctx, "error enriching remote account: %v", err)
-		return nil, nil, gtserror.Newf("error enriching remote account: %w", err)
+		return nil, nil, gtserror.Newf("%w", err)
 	}
 
 	if accountable != nil {
-		// This account was updated, enqueue re-dereference featured posts.
-		d.state.Workers.Federator.MustEnqueueCtx(ctx, func(ctx context.Context) {
+		// This account was updated, enqueue re-dereference featured posts + stats.
+		d.state.Workers.Dereference.Queue.Push(func(ctx context.Context) {
 			if err := d.dereferenceAccountFeatured(ctx, requestUser, latest); err != nil {
 				log.Errorf(ctx, "error fetching account featured collection: %v", err)
 			}
+
+			if err := d.dereferenceAccountStats(ctx, requestUser, latest); err != nil {
+				log.Errorf(ctx, "error fetching account stats: %v", err)
+			}
 		})
 	}
 
@@ -362,7 +420,7 @@ func (d *Dereferencer) RefreshAccountAsync(
 	}
 
 	// Enqueue a worker function to enrich this account async.
-	d.state.Workers.Federator.MustEnqueueCtx(ctx, func(ctx context.Context) {
+	d.state.Workers.Dereference.Queue.Push(func(ctx context.Context) {
 		latest, accountable, err := d.enrichAccountSafely(ctx, requestUser, uri, account, accountable)
 		if err != nil {
 			log.Errorf(ctx, "error enriching remote account: %v", err)
@@ -370,10 +428,14 @@ func (d *Dereferencer) RefreshAccountAsync(
 		}
 
 		if accountable != nil {
-			// This account was updated, enqueue re-dereference featured posts.
+			// This account was updated, enqueue re-dereference featured posts + stats.
 			if err := d.dereferenceAccountFeatured(ctx, requestUser, latest); err != nil {
 				log.Errorf(ctx, "error fetching account featured collection: %v", err)
 			}
+
+			if err := d.dereferenceAccountStats(ctx, requestUser, latest); err != nil {
+				log.Errorf(ctx, "error fetching account stats: %v", err)
+			}
 		}
 	})
 }
@@ -478,10 +540,16 @@ func (d *Dereferencer) enrichAccount(
 	}
 
 	if account.Username != "" {
-		// A username was provided so we can attempt a webfinger, this ensures up-to-date accountdomain info.
-		accDomain, accURI, err := d.fingerRemoteAccount(ctx, tsport, account.Username, account.Domain)
-		switch {
+		// A username was provided so we can attempt to webfinger,
+		// this ensures up-to-date account domain, and handles some
+		// edge cases where servers don't provide a preferred_username.
+		accUsername, accDomain, accURI, err := d.fingerRemoteAccount(ctx,
+			tsport,
+			account.Username,
+			account.Domain,
+		)
 
+		switch {
 		case err != nil && account.URI == "":
 			// This is a new account (to us) with username@domain
 			// but failed webfinger, nothing more we can do.
@@ -496,7 +564,7 @@ func (d *Dereferencer) enrichAccount(
 				account.Username, account.Domain, err,
 			)
 
-		case err == nil && account.Domain != accDomain:
+		case account.Domain != accDomain:
 			// After webfinger, we now have correct account domain from which we can do a final DB check.
 			alreadyAcc, err := d.state.DB.GetAccountByUsernameDomain(ctx, account.Username, accDomain)
 			if err != nil && !errors.Is(err, db.ErrNoEntries) {
@@ -518,11 +586,14 @@ func (d *Dereferencer) enrichAccount(
 			// or the stub account we were passed.
 			fallthrough
 
-		case err == nil:
+		default:
 			// Update account with latest info.
 			account.URI = accURI.String()
 			account.Domain = accDomain
 			uri = accURI
+
+			// Specifically only update username if not already set.
+			account.Username = cmp.Or(account.Username, accUsername)
 		}
 	}
 
@@ -531,19 +602,14 @@ func (d *Dereferencer) enrichAccount(
 		// must parse from account.
 		uri, err = url.Parse(account.URI)
 		if err != nil {
-			return nil, nil, gtserror.Newf(
-				"invalid uri %q: %w",
-				account.URI, gtserror.SetUnretrievable(err),
-			)
+			err := gtserror.Newf("invalid uri %q: %w", account.URI, err)
+			return nil, nil, gtserror.SetUnretrievable(err)
 		}
 
 		// Check URI scheme ahead of time for more useful errs.
 		if uri.Scheme != "http" && uri.Scheme != "https" {
-			err := errors.New("account URI scheme must be http or https")
-			return nil, nil, gtserror.Newf(
-				"invalid uri %q: %w",
-				account.URI, gtserror.SetUnretrievable(err),
-			)
+			err := gtserror.Newf("invalid uri %q: scheme must be http(s)", account.URI)
+			return nil, nil, gtserror.SetUnretrievable(err)
 		}
 	}
 
@@ -564,7 +630,9 @@ func (d *Dereferencer) enrichAccount(
 	d.startHandshake(requestUser, uri)
 	defer d.stopHandshake(requestUser, uri)
 
-	if apubAcc == nil {
+	var resolve bool
+
+	if resolve = (apubAcc == nil); resolve {
 		// We were not given any (partial) ActivityPub
 		// version of this account as a parameter.
 		// Dereference latest version of the account.
@@ -583,7 +651,7 @@ func (d *Dereferencer) enrichAccount(
 		if err != nil {
 			// ResolveAccountable will set gtserror.WrongType
 			// on the returned error, so we don't need to do it here.
-			err = gtserror.Newf("error resolving accountable %s: %w", uri, err)
+			err := gtserror.Newf("error resolving accountable %s: %w", uri, err)
 			return nil, nil, err
 		}
 
@@ -601,7 +669,16 @@ func (d *Dereferencer) enrichAccount(
 				return nil, nil, gtserror.Newf("db error getting account after redirects: %w", err)
 			}
 
-			if alreadyAcc != nil {
+			switch {
+			case alreadyAcc == nil:
+				// nothing to do
+
+			case alreadyAcc.IsLocal():
+				// Request eventually redirected to a
+				// local account. Return it as-is here.
+				return alreadyAcc, nil, nil
+
+			default:
 				// We had this account stored
 				// under discovered final URI.
 				//
@@ -630,15 +707,18 @@ func (d *Dereferencer) enrichAccount(
 	latestAcc, err := d.converter.ASRepresentationToAccount(ctx,
 		apubAcc,
 		account.Domain,
+		account.Username,
 	)
 	if err != nil {
 		// ASRepresentationToAccount will set Malformed on the
 		// returned error, so we don't need to do it here.
-		err = gtserror.Newf("error converting accountable to gts model for account %s: %w", uri, err)
+		err := gtserror.Newf("error converting %s to gts model: %w", uri, err)
 		return nil, nil, err
 	}
 
 	if account.Username == "" {
+		var accUsername string
+
 		// Assume the host from the
 		// ActivityPub representation.
 		id := ap.GetJSONLDId(apubAcc)
@@ -659,7 +739,7 @@ func (d *Dereferencer) enrichAccount(
 		// https://example.org/@someone@somewhere.else and we've been redirected
 		// from example.org to somewhere.else: we want to take somewhere.else
 		// as the accountDomain then, not the example.org we were redirected from.
-		latestAcc.Domain, _, err = d.fingerRemoteAccount(ctx,
+		accUsername, latestAcc.Domain, _, err = d.fingerRemoteAccount(ctx,
 			tsport,
 			latestAcc.Username,
 			accHost,
@@ -672,22 +752,44 @@ func (d *Dereferencer) enrichAccount(
 				latestAcc.Username, accHost, err,
 			)
 		}
+
+		// Specifically only update username if not already set.
+		latestAcc.Username = cmp.Or(latestAcc.Username, accUsername)
 	}
 
-	if latestAcc.Domain == "" {
-		// Ensure we have a domain set by this point,
-		// otherwise it gets stored as a local user!
-		return nil, nil, gtserror.Newf("empty domain for %s", uri)
-	}
-
-	// Ensure the final parsed account URI / URL matches
+	// Ensure the final parsed account URI matches
 	// the input URI we fetched (or received) it as.
-	if expect := uri.String(); latestAcc.URI != expect &&
-		latestAcc.URL != expect {
+	if matches, err := util.URIMatches(
+		uri,
+		append(
+			ap.GetURL(apubAcc),      // account URL(s)
+			ap.GetJSONLDId(apubAcc), // account URI
+		)...,
+	); err != nil {
 		return nil, nil, gtserror.Newf(
-			"dereferenced account uri %s does not match %s",
-			latestAcc.URI, expect,
+			"error checking account uri %s: %w",
+			latestAcc.URI, err,
 		)
+	} else if !matches {
+		return nil, nil, gtserror.Newf(
+			"account uri %s does not match %s",
+			latestAcc.URI, uri,
+		)
+	}
+
+	// Ensure this isn't a local account,
+	// or a remote masquerading as such!
+	if latestAcc.IsLocal() {
+		return nil, nil, gtserror.Newf("cannot dereference local account %s", uri)
+	}
+
+	// Get current time.
+	now := time.Now()
+
+	// Before expending any further serious compute, we need
+	// to ensure account keys haven't unexpectedly been changed.
+	if !verifyAccountKeysOnUpdate(account, latestAcc, now, !resolve) {
+		return nil, nil, gtserror.Newf("account %s pubkey has changed (key rotation required?)", uri)
 	}
 
 	/*
@@ -695,39 +797,37 @@ func (d *Dereferencer) enrichAccount(
 		representation of the target account, derived from
 		a combination of webfinger lookups and dereferencing.
 		Further fetching beyond this point is for peripheral
-		things like account avatar, header, emojis.
+		things like account avatar, header, emojis, stats.
 	*/
 
 	// Ensure internal db ID is
 	// set and update fetch time.
 	latestAcc.ID = account.ID
-	latestAcc.FetchedAt = time.Now()
+	latestAcc.FetchedAt = now
+	latestAcc.UpdatedAt = now
 
 	// Ensure the account's avatar media is populated, passing in existing to check for chages.
-	if err := d.fetchRemoteAccountAvatar(ctx, tsport, account, latestAcc); err != nil {
+	if err := d.fetchAccountAvatar(ctx, requestUser, account, latestAcc, apubAcc); err != nil {
 		log.Errorf(ctx, "error fetching remote avatar for account %s: %v", uri, err)
 	}
 
 	// Ensure the account's avatar media is populated, passing in existing to check for chages.
-	if err := d.fetchRemoteAccountHeader(ctx, tsport, account, latestAcc); err != nil {
+	if err := d.fetchAccountHeader(ctx, requestUser, account, latestAcc, apubAcc); err != nil {
 		log.Errorf(ctx, "error fetching remote header for account %s: %v", uri, err)
 	}
 
 	// Fetch the latest remote account emoji IDs used in account display name/bio.
-	if _, err = d.fetchRemoteAccountEmojis(ctx, latestAcc, requestUser); err != nil {
+	if err = d.fetchAccountEmojis(ctx, account, latestAcc); err != nil {
 		log.Errorf(ctx, "error fetching remote emojis for account %s: %v", uri, err)
 	}
 
 	if account.IsNew() {
 		// Prefer published/created time from
-		// apubAcc, fall back to FetchedAt value.
+		// apubAcc, fall back to current time.
 		if latestAcc.CreatedAt.IsZero() {
-			latestAcc.CreatedAt = latestAcc.FetchedAt
+			latestAcc.CreatedAt = now
 		}
 
-		// Set time of update from the last-fetched date.
-		latestAcc.UpdatedAt = latestAcc.FetchedAt
-
 		// This is new, put it in the database.
 		err := d.state.DB.PutAccount(ctx, latestAcc)
 		if err != nil {
@@ -740,9 +840,6 @@ func (d *Dereferencer) enrichAccount(
 			latestAcc.CreatedAt = account.CreatedAt
 		}
 
-		// Set time of update from the last-fetched date.
-		latestAcc.UpdatedAt = latestAcc.FetchedAt
-
 		// This is an existing account, update the model in the database.
 		if err := d.state.DB.UpdateAccount(ctx, latestAcc); err != nil {
 			return nil, nil, gtserror.Newf("error updating database: %w", err)
@@ -752,288 +849,332 @@ func (d *Dereferencer) enrichAccount(
 	return latestAcc, apubAcc, nil
 }
 
-func (d *Dereferencer) fetchRemoteAccountAvatar(ctx context.Context, tsport transport.Transport, existing, latestAcc *gtsmodel.Account) error {
+func (d *Dereferencer) fetchAccountAvatar(
+	ctx context.Context,
+	requestUser string,
+	existingAcc *gtsmodel.Account,
+	latestAcc *gtsmodel.Account,
+	apubAcc ap.Accountable,
+) error {
 	if latestAcc.AvatarRemoteURL == "" {
 		// No avatar set on newest model, leave
 		// latest avatar attachment ID empty.
 		return nil
 	}
 
-	// By default we keep the previous media attachment ID. This will only
-	// be changed if and when we have the new media loaded into storage.
-	latestAcc.AvatarMediaAttachmentID = existing.AvatarMediaAttachmentID
+	avatarDescription := ap.ExtractIconDescription(apubAcc)
 
-	// If we had a media attachment ID already, and the URL
-	// of the attachment hasn't changed from existing -> latest,
-	// then we may be able to just keep our existing attachment
-	// without having to make any remote calls.
-	if latestAcc.AvatarMediaAttachmentID != "" &&
-		existing.AvatarRemoteURL == latestAcc.AvatarRemoteURL {
+	// Check for an existing stored media attachment
+	// specifically with unchanged remote URL we can use.
+	if existingAcc.AvatarMediaAttachmentID != "" &&
+		existingAcc.AvatarRemoteURL == latestAcc.AvatarRemoteURL {
 
-		// Ensure we have media attachment with the known ID.
-		media, err := d.state.DB.GetAttachmentByID(ctx, existing.AvatarMediaAttachmentID)
+		// Fetch the existing avatar media attachment with ID.
+		existing, err := d.state.DB.GetAttachmentByID(ctx,
+			existingAcc.AvatarMediaAttachmentID,
+		)
 		if err != nil && !errors.Is(err, db.ErrNoEntries) {
-			return gtserror.Newf("error getting attachment %s: %w", existing.AvatarMediaAttachmentID, err)
+			return gtserror.Newf("error getting attachment %s: %w", existingAcc.AvatarMediaAttachmentID, err)
 		}
 
-		// Ensure attachment has correct properties.
-		if media != nil && media.RemoteURL == latestAcc.AvatarRemoteURL {
-			// We already have the most up-to-date
-			// media attachment, keep using it.
+		if existing != nil {
+			// Ensuring existing attachment is up-to-date
+			// and any recaching is performed if required.
+			existing, err := d.updateAttachment(ctx,
+				requestUser,
+				existing,
+				nil,
+			)
+
+			if existing.Description != avatarDescription {
+				existing.Description = avatarDescription
+				if err := d.state.DB.UpdateAttachment(
+					ctx,
+					existing,
+					"description",
+				); err != nil {
+					err := gtserror.Newf("db error updating existing avatar description: %w", err)
+					return gtserror.NewErrorInternalError(err)
+				}
+			}
+
+			if err != nil {
+				log.Errorf(ctx, "error updating existing attachment: %v", err)
+
+				// specifically do NOT return nil here,
+				// we already have a model, we don't
+				// want to drop it from the account, just
+				// log that an update for it failed.
+			}
+
+			// Set the avatar attachment on account model.
+			latestAcc.AvatarMediaAttachment = existing
+			latestAcc.AvatarMediaAttachmentID = existing.ID
+
 			return nil
 		}
 	}
 
-	// If we reach here, we know we need to fetch the most
-	// up-to-date version of the attachment from remote.
-
-	// Parse and validate the newly provided media URL.
-	avatarURI, err := url.Parse(latestAcc.AvatarRemoteURL)
+	// Fetch newly changed avatar.
+	attachment, err := d.GetMedia(ctx,
+		requestUser,
+		latestAcc.ID,
+		latestAcc.AvatarRemoteURL,
+		media.AdditionalMediaInfo{
+			Avatar:      util.Ptr(true),
+			RemoteURL:   &latestAcc.AvatarRemoteURL,
+			Description: &avatarDescription,
+		},
+	)
 	if err != nil {
-		return gtserror.Newf("error parsing url %s: %w", latestAcc.AvatarRemoteURL, err)
-	}
-
-	// Acquire lock for derefs map.
-	unlock := d.state.FedLocks.Lock(latestAcc.AvatarRemoteURL)
-	unlock = util.DoOnce(unlock)
-	defer unlock()
-
-	// Look for an existing dereference in progress.
-	processing, ok := d.derefAvatars[latestAcc.AvatarRemoteURL]
-
-	if !ok {
-		// Set the media data function to dereference avatar from URI.
-		data := func(ctx context.Context) (io.ReadCloser, int64, error) {
-			return tsport.DereferenceMedia(ctx, avatarURI)
+		if attachment == nil {
+			return gtserror.Newf("error loading attachment %s: %w", latestAcc.AvatarRemoteURL, err)
 		}
 
-		// Create new media processing request from the media manager instance.
-		processing = d.mediaManager.PreProcessMedia(data, latestAcc.ID, &media.AdditionalMediaInfo{
-			Avatar:    func() *bool { v := true; return &v }(),
-			RemoteURL: &latestAcc.AvatarRemoteURL,
-		})
-
-		// Store media in map to mark as processing.
-		d.derefAvatars[latestAcc.AvatarRemoteURL] = processing
-
-		defer func() {
-			// On exit safely remove media from map.
-			unlock := d.state.FedLocks.Lock(latestAcc.AvatarRemoteURL)
-			delete(d.derefAvatars, latestAcc.AvatarRemoteURL)
-			unlock()
-		}()
+		// non-fatal error occurred during loading, still use it.
+		log.Warnf(ctx, "partially loaded attachment: %v", err)
 	}
 
-	// Unlock map.
-	unlock()
-
-	// Start media attachment loading (blocking call).
-	if _, err := processing.LoadAttachment(ctx); err != nil {
-		return gtserror.Newf("error loading attachment %s: %w", latestAcc.AvatarRemoteURL, err)
-	}
-
-	// Set the newly loaded avatar media attachment ID.
-	latestAcc.AvatarMediaAttachmentID = processing.AttachmentID()
+	// Set the avatar attachment on account model.
+	latestAcc.AvatarMediaAttachment = attachment
+	latestAcc.AvatarMediaAttachmentID = attachment.ID
 
 	return nil
 }
 
-func (d *Dereferencer) fetchRemoteAccountHeader(ctx context.Context, tsport transport.Transport, existing, latestAcc *gtsmodel.Account) error {
+func (d *Dereferencer) fetchAccountHeader(
+	ctx context.Context,
+	requestUser string,
+	existingAcc *gtsmodel.Account,
+	latestAcc *gtsmodel.Account,
+	apubAcc ap.Accountable,
+) error {
 	if latestAcc.HeaderRemoteURL == "" {
 		// No header set on newest model, leave
 		// latest header attachment ID empty.
 		return nil
 	}
 
-	// By default we keep the previous media attachment ID. This will only
-	// be changed if and when we have the new media loaded into storage.
-	latestAcc.HeaderMediaAttachmentID = existing.HeaderMediaAttachmentID
+	headerDescription := ap.ExtractImageDescription(apubAcc)
 
-	// If we had a media attachment ID already, and the URL
-	// of the attachment hasn't changed from existing -> latest,
-	// then we may be able to just keep our existing attachment
-	// without having to make any remote calls.
-	if latestAcc.HeaderMediaAttachmentID != "" &&
-		existing.HeaderRemoteURL == latestAcc.HeaderRemoteURL {
+	// Check for an existing stored media attachment
+	// specifically with unchanged remote URL we can use.
+	if existingAcc.HeaderMediaAttachmentID != "" &&
+		existingAcc.HeaderRemoteURL == latestAcc.HeaderRemoteURL {
 
-		// Ensure we have media attachment with the known ID.
-		media, err := d.state.DB.GetAttachmentByID(ctx, existing.HeaderMediaAttachmentID)
+		// Fetch the existing header media attachment with ID.
+		existing, err := d.state.DB.GetAttachmentByID(ctx,
+			existingAcc.HeaderMediaAttachmentID,
+		)
 		if err != nil && !errors.Is(err, db.ErrNoEntries) {
-			return gtserror.Newf("error getting attachment %s: %w", existing.HeaderMediaAttachmentID, err)
+			return gtserror.Newf("error getting attachment %s: %w", existingAcc.HeaderMediaAttachmentID, err)
 		}
 
-		// Ensure attachment has correct properties.
-		if media != nil && media.RemoteURL == latestAcc.HeaderRemoteURL {
-			// We already have the most up-to-date
-			// media attachment, keep using it.
+		if existing.Description != headerDescription {
+			existing.Description = headerDescription
+			if err := d.state.DB.UpdateAttachment(
+				ctx,
+				existing,
+				"description",
+			); err != nil {
+				err := gtserror.Newf("db error updating existing header description: %w", err)
+				return gtserror.NewErrorInternalError(err)
+			}
+		}
+
+		if existing != nil {
+			// Ensuring existing attachment is up-to-date
+			// and any recaching is performed if required.
+			existing, err := d.updateAttachment(ctx,
+				requestUser,
+				existing,
+				nil,
+			)
+
+			if err != nil {
+				log.Errorf(ctx, "error updating existing attachment: %v", err)
+
+				// specifically do NOT return nil here,
+				// we already have a model, we don't
+				// want to drop it from the account, just
+				// log that an update for it failed.
+			}
+
+			// Set the header attachment on account model.
+			latestAcc.HeaderMediaAttachment = existing
+			latestAcc.HeaderMediaAttachmentID = existing.ID
+
 			return nil
 		}
 	}
 
-	// If we reach here, we know we need to fetch the most
-	// up-to-date version of the attachment from remote.
-
-	// Parse and validate the newly provided media URL.
-	headerURI, err := url.Parse(latestAcc.HeaderRemoteURL)
+	// Fetch newly changed header.
+	attachment, err := d.GetMedia(ctx,
+		requestUser,
+		latestAcc.ID,
+		latestAcc.HeaderRemoteURL,
+		media.AdditionalMediaInfo{
+			Header:      util.Ptr(true),
+			RemoteURL:   &latestAcc.HeaderRemoteURL,
+			Description: &headerDescription,
+		},
+	)
 	if err != nil {
-		return gtserror.Newf("error parsing url %s: %w", latestAcc.HeaderRemoteURL, err)
-	}
-
-	// Acquire lock for derefs map.
-	unlock := d.state.FedLocks.Lock(latestAcc.HeaderRemoteURL)
-	unlock = util.DoOnce(unlock)
-	defer unlock()
-
-	// Look for an existing dereference in progress.
-	processing, ok := d.derefHeaders[latestAcc.HeaderRemoteURL]
-
-	if !ok {
-		// Set the media data function to dereference avatar from URI.
-		data := func(ctx context.Context) (io.ReadCloser, int64, error) {
-			return tsport.DereferenceMedia(ctx, headerURI)
+		if attachment == nil {
+			return gtserror.Newf("error loading attachment %s: %w", latestAcc.HeaderRemoteURL, err)
 		}
 
-		// Create new media processing request from the media manager instance.
-		processing = d.mediaManager.PreProcessMedia(data, latestAcc.ID, &media.AdditionalMediaInfo{
-			Header:    func() *bool { v := true; return &v }(),
-			RemoteURL: &latestAcc.HeaderRemoteURL,
-		})
-
-		// Store media in map to mark as processing.
-		d.derefHeaders[latestAcc.HeaderRemoteURL] = processing
-
-		defer func() {
-			// On exit safely remove media from map.
-			unlock := d.state.FedLocks.Lock(latestAcc.HeaderRemoteURL)
-			delete(d.derefHeaders, latestAcc.HeaderRemoteURL)
-			unlock()
-		}()
+		// non-fatal error occurred during loading, still use it.
+		log.Warnf(ctx, "partially loaded attachment: %v", err)
 	}
 
-	// Unlock map.
-	unlock()
-
-	// Start media attachment loading (blocking call).
-	if _, err := processing.LoadAttachment(ctx); err != nil {
-		return gtserror.Newf("error loading attachment %s: %w", latestAcc.HeaderRemoteURL, err)
-	}
-
-	// Set the newly loaded avatar media attachment ID.
-	latestAcc.HeaderMediaAttachmentID = processing.AttachmentID()
+	// Set the header attachment on account model.
+	latestAcc.HeaderMediaAttachment = attachment
+	latestAcc.HeaderMediaAttachmentID = attachment.ID
 
 	return nil
 }
 
-func (d *Dereferencer) fetchRemoteAccountEmojis(ctx context.Context, targetAccount *gtsmodel.Account, requestingUsername string) (bool, error) {
-	maybeEmojis := targetAccount.Emojis
-	maybeEmojiIDs := targetAccount.EmojiIDs
-
-	// It's possible that the account had emoji IDs set on it, but not Emojis
-	// themselves, depending on how it was fetched before being passed to us.
-	//
-	// If we only have IDs, fetch the emojis from the db. We know they're in
-	// there or else they wouldn't have IDs.
-	if len(maybeEmojiIDs) > len(maybeEmojis) {
-		maybeEmojis = make([]*gtsmodel.Emoji, 0, len(maybeEmojiIDs))
-		for _, emojiID := range maybeEmojiIDs {
-			maybeEmoji, err := d.state.DB.GetEmojiByID(ctx, emojiID)
-			if err != nil {
-				return false, err
-			}
-			maybeEmojis = append(maybeEmojis, maybeEmoji)
-		}
-	}
-
-	// For all the maybe emojis we have, we either fetch them from the database
-	// (if we haven't already), or dereference them from the remote instance.
-	gotEmojis, err := d.populateEmojis(ctx, maybeEmojis, requestingUsername)
-	if err != nil {
-		return false, err
-	}
-
-	// Extract the ID of each fetched or dereferenced emoji, so we can attach
-	// this to the account if necessary.
-	gotEmojiIDs := make([]string, 0, len(gotEmojis))
-	for _, e := range gotEmojis {
-		gotEmojiIDs = append(gotEmojiIDs, e.ID)
-	}
-
-	var (
-		changed  = false // have the emojis for this account changed?
-		maybeLen = len(maybeEmojis)
-		gotLen   = len(gotEmojis)
+func (d *Dereferencer) fetchAccountEmojis(
+	ctx context.Context,
+	existing *gtsmodel.Account,
+	account *gtsmodel.Account,
+) error {
+	// Fetch the updated emojis for our account.
+	emojis, changed, err := d.fetchEmojis(ctx,
+		existing.Emojis,
+		account.Emojis,
 	)
-
-	// if the length of everything is zero, this is simple:
-	// nothing has changed and there's nothing to do
-	if maybeLen == 0 && gotLen == 0 {
-		return changed, nil
+	if err != nil {
+		return gtserror.Newf("error fetching emojis: %w", err)
 	}
 
-	// if the *amount* of emojis on the account has changed, then the got emojis
-	// are definitely different from the previous ones (if there were any) --
-	// the account has either more or fewer emojis set on it now, so take the
-	// discovered emojis as the new correct ones.
-	if maybeLen != gotLen {
-		changed = true
-		targetAccount.Emojis = gotEmojis
-		targetAccount.EmojiIDs = gotEmojiIDs
-		return changed, nil
+	if !changed {
+		// Use existing account emoji objects.
+		account.EmojiIDs = existing.EmojiIDs
+		account.Emojis = existing.Emojis
+		return nil
 	}
 
-	// if the lengths are the same but not all of the slices are
-	// zero, something *might* have changed, so we have to check
+	// Set latest emojis.
+	account.Emojis = emojis
 
-	// 1. did we have emojis before that we don't have now?
-	for _, maybeEmoji := range maybeEmojis {
-		var stillPresent bool
-
-		for _, gotEmoji := range gotEmojis {
-			if maybeEmoji.URI == gotEmoji.URI {
-				// the emoji we maybe had is still present now,
-				// so we can stop checking gotEmojis
-				stillPresent = true
-				break
-			}
-		}
-
-		if !stillPresent {
-			// at least one maybeEmoji is no longer present in
-			// the got emojis, so we can stop checking now
-			changed = true
-			targetAccount.Emojis = gotEmojis
-			targetAccount.EmojiIDs = gotEmojiIDs
-			return changed, nil
-		}
+	// Iterate over and set changed emoji IDs.
+	account.EmojiIDs = make([]string, len(emojis))
+	for i, emoji := range emojis {
+		account.EmojiIDs[i] = emoji.ID
 	}
 
-	// 2. do we have emojis now that we didn't have before?
-	for _, gotEmoji := range gotEmojis {
-		var wasPresent bool
+	return nil
+}
 
-		for _, maybeEmoji := range maybeEmojis {
-			// check emoji IDs here as well, because unreferenced
-			// maybe emojis we didn't already have would not have
-			// had IDs set on them yet
-			if gotEmoji.URI == maybeEmoji.URI && gotEmoji.ID == maybeEmoji.ID {
-				// this got emoji was present already in the maybeEmoji,
-				// so we can stop checking through maybeEmojis
-				wasPresent = true
-				break
-			}
-		}
-
-		if !wasPresent {
-			// at least one gotEmojis was not present in
-			// the maybeEmojis, so we can stop checking now
-			changed = true
-			targetAccount.Emojis = gotEmojis
-			targetAccount.EmojiIDs = gotEmojiIDs
-			return changed, nil
-		}
+func (d *Dereferencer) dereferenceAccountStats(
+	ctx context.Context,
+	requestUser string,
+	account *gtsmodel.Account,
+) error {
+	// Ensure we have a stats model for this account.
+	if err := d.state.DB.PopulateAccountStats(ctx, account); err != nil {
+		return gtserror.Newf("db error getting account stats: %w", err)
 	}
 
-	return changed, nil
+	// We want to update stats by getting remote
+	// followers/following/statuses counts for
+	// this account.
+	//
+	// If we fail getting any particular stat,
+	// it will just fall back to counting local.
+
+	// Followers first.
+	if count, err := d.countCollection(
+		ctx,
+		account.FollowersURI,
+		requestUser,
+	); err != nil {
+		// Log this but don't bail.
+		log.Warnf(ctx,
+			"couldn't count followers for @%s@%s: %v",
+			account.Username, account.Domain, err,
+		)
+	} else if count > 0 {
+		// Positive integer is useful!
+		account.Stats.FollowersCount = &count
+	}
+
+	// Now following.
+	if count, err := d.countCollection(
+		ctx,
+		account.FollowingURI,
+		requestUser,
+	); err != nil {
+		// Log this but don't bail.
+		log.Warnf(ctx,
+			"couldn't count following for @%s@%s: %v",
+			account.Username, account.Domain, err,
+		)
+	} else if count > 0 {
+		// Positive integer is useful!
+		account.Stats.FollowingCount = &count
+	}
+
+	// Now statuses count.
+	if count, err := d.countCollection(
+		ctx,
+		account.OutboxURI,
+		requestUser,
+	); err != nil {
+		// Log this but don't bail.
+		log.Warnf(ctx,
+			"couldn't count statuses for @%s@%s: %v",
+			account.Username, account.Domain, err,
+		)
+	} else if count > 0 {
+		// Positive integer is useful!
+		account.Stats.StatusesCount = &count
+	}
+
+	// Update stats now.
+	if err := d.state.DB.UpdateAccountStats(
+		ctx,
+		account.Stats,
+		"followers_count",
+		"following_count",
+		"statuses_count",
+	); err != nil {
+		return gtserror.Newf("db error updating account stats: %w", err)
+	}
+
+	return nil
+}
+
+// countCollection parses the given uriStr,
+// dereferences the result as a collection
+// type, and returns total items as 0, or
+// a positive integer, or -1 if total items
+// cannot be counted.
+//
+// Error will be returned for invalid non-empty
+// URIs or dereferencing isses.
+func (d *Dereferencer) countCollection(
+	ctx context.Context,
+	uriStr string,
+	requestUser string,
+) (int, error) {
+	if uriStr == "" {
+		return -1, nil
+	}
+
+	uri, err := url.Parse(uriStr)
+	if err != nil {
+		return -1, err
+	}
+
+	collect, err := d.dereferenceCollection(ctx, requestUser, uri)
+	if err != nil {
+		return -1, err
+	}
+
+	return collect.TotalItems(), nil
 }
 
 // dereferenceAccountFeatured dereferences an account's featuredCollectionURI (if not empty). For each discovered status, this status will
