@@ -51,6 +51,7 @@ func (d *Dereferencer) GetEmoji(
 	remoteURL string,
 	info media.AdditionalEmojiInfo,
 	refresh bool,
+	async bool,
 ) (
 	*gtsmodel.Emoji,
 	error,
@@ -66,7 +67,7 @@ func (d *Dereferencer) GetEmoji(
 
 	if emoji != nil {
 		// This was an existing emoji, pass to refresh func.
-		return d.RefreshEmoji(ctx, emoji, info, refresh)
+		return d.RefreshEmoji(ctx, emoji, info, refresh, async)
 	}
 
 	if domain == "" {
@@ -74,18 +75,16 @@ func (d *Dereferencer) GetEmoji(
 		return nil, gtserror.SetUnretrievable(err)
 	}
 
-	// Generate shortcode domain for locks + logging.
-	shortcodeDomain := shortcode + "@" + domain
-
 	// Pass along for safe processing.
 	return d.processEmojiSafely(ctx,
-		shortcodeDomain,
+		shortcode,
+		domain,
 		func() (*media.ProcessingEmoji, error) {
 
 			// Ensure we have a valid remote URL.
 			url, err := url.Parse(remoteURL)
 			if err != nil {
-				err := gtserror.Newf("invalid image remote url %s for emoji %s: %w", remoteURL, shortcodeDomain, err)
+				err := gtserror.Newf("invalid image remote url %s for emoji %s@%s: %w", remoteURL, shortcode, domain, err)
 				return nil, err
 			}
 
@@ -112,6 +111,8 @@ func (d *Dereferencer) GetEmoji(
 				info,
 			)
 		},
+		false, // refresh
+		async,
 	)
 }
 
@@ -130,6 +131,7 @@ func (d *Dereferencer) RefreshEmoji(
 	emoji *gtsmodel.Emoji,
 	info media.AdditionalEmojiInfo,
 	force bool,
+	async bool,
 ) (
 	*gtsmodel.Emoji,
 	error,
@@ -162,7 +164,7 @@ func (d *Dereferencer) RefreshEmoji(
 		// We still want to make sure
 		// the emoji is cached. Simply
 		// check whether emoji is cached.
-		return d.RecacheEmoji(ctx, emoji)
+		return d.RecacheEmoji(ctx, emoji, async)
 	}
 
 	// Can't refresh local.
@@ -170,19 +172,17 @@ func (d *Dereferencer) RefreshEmoji(
 		return emoji, nil
 	}
 
-	// Get shortcode domain for locks + logging.
-	shortcodeDomain := emoji.ShortcodeDomain()
-
 	// Ensure we have a valid image remote URL.
 	url, err := url.Parse(emoji.ImageRemoteURL)
 	if err != nil {
-		err := gtserror.Newf("invalid image remote url %s for emoji %s: %w", emoji.ImageRemoteURL, shortcodeDomain, err)
+		err := gtserror.Newf("invalid image remote url %s for emoji %s@%s: %w", emoji.ImageRemoteURL, emoji.Shortcode, emoji.Domain, err)
 		return nil, err
 	}
 
 	// Pass along for safe processing.
 	return d.processEmojiSafely(ctx,
-		shortcodeDomain,
+		emoji.Shortcode,
+		emoji.Domain,
 		func() (*media.ProcessingEmoji, error) {
 
 			// Acquire new instance account transport for emoji dereferencing.
@@ -207,6 +207,8 @@ func (d *Dereferencer) RefreshEmoji(
 				info,
 			)
 		},
+		true, // refresh
+		async,
 	)
 }
 
@@ -222,6 +224,7 @@ func (d *Dereferencer) RefreshEmoji(
 func (d *Dereferencer) RecacheEmoji(
 	ctx context.Context,
 	emoji *gtsmodel.Emoji,
+	async bool,
 ) (
 	*gtsmodel.Emoji,
 	error,
@@ -236,19 +239,17 @@ func (d *Dereferencer) RecacheEmoji(
 		return emoji, nil
 	}
 
-	// Get shortcode domain for locks + logging.
-	shortcodeDomain := emoji.ShortcodeDomain()
-
 	// Ensure we have a valid image remote URL.
 	url, err := url.Parse(emoji.ImageRemoteURL)
 	if err != nil {
-		err := gtserror.Newf("invalid image remote url %s for emoji %s: %w", emoji.ImageRemoteURL, shortcodeDomain, err)
+		err := gtserror.Newf("invalid image remote url %s for emoji %s@%s: %w", emoji.ImageRemoteURL, emoji.Shortcode, emoji.Domain, err)
 		return nil, err
 	}
 
 	// Pass along for safe processing.
 	return d.processEmojiSafely(ctx,
-		shortcodeDomain,
+		emoji.Shortcode,
+		emoji.Domain,
 		func() (*media.ProcessingEmoji, error) {
 
 			// Acquire new instance account transport for emoji dereferencing.
@@ -272,22 +273,29 @@ func (d *Dereferencer) RecacheEmoji(
 				data,
 			)
 		},
+		false, // refresh
+		async,
 	)
-
 }
 
 // processingEmojiSafely provides concurrency-safe processing of
 // an emoji with given shortcode+domain. if a copy of the emoji is
 // not already being processed, the given 'process' callback will
-// be used to generate new *media.ProcessingEmoji{} instance.
+// be used to generate new *media.ProcessingEmoji{} instance. async
+// determines whether to load it immediately, or in the background.
 func (d *Dereferencer) processEmojiSafely(
 	ctx context.Context,
-	shortcodeDomain string,
+	shortcode string,
+	domain string,
 	process func() (*media.ProcessingEmoji, error),
+	refresh bool,
+	async bool,
 ) (
 	emoji *gtsmodel.Emoji,
 	err error,
 ) {
+	// Generate shortcode@domain for locks + logging.
+	shortcodeDomain := shortcode + "@" + domain
 
 	// Acquire map lock.
 	d.derefEmojisMu.Lock()
@@ -301,6 +309,23 @@ func (d *Dereferencer) processEmojiSafely(
 	processing, ok := d.derefEmojis[shortcodeDomain]
 
 	if !ok {
+		if !refresh {
+			// Before starting processing, ensure the information
+			// we have about emoji (i.e. getting here) is up-to-date.
+			emoji, err := d.state.DB.GetEmojiByShortcodeDomain(ctx,
+				shortcode,
+				domain,
+			)
+			if err != nil && !errors.Is(err, db.ErrNoEntries) {
+				return nil, gtserror.Newf("error fetching emoji from db: %w", err)
+			}
+
+			// If just been cached, use this!
+			if emoji != nil && *emoji.Cached {
+				return emoji, nil
+			}
+		}
+
 		// Start new processing emoji.
 		processing, err = process()
 		if err != nil {
@@ -309,25 +334,34 @@ func (d *Dereferencer) processEmojiSafely(
 
 		// Add processing emoji media to hash map.
 		d.derefEmojis[shortcodeDomain] = processing
+	}
 
+	// Unlock map.
+	unlock()
+
+	if async {
+		emoji = processing.LoadAsync(func() {
+			// Remove on finish.
+			d.derefEmojisMu.Lock()
+			delete(d.derefEmojis, shortcodeDomain)
+			d.derefEmojisMu.Unlock()
+		})
+	} else {
 		defer func() {
 			// Remove on finish.
 			d.derefEmojisMu.Lock()
 			delete(d.derefEmojis, shortcodeDomain)
 			d.derefEmojisMu.Unlock()
 		}()
-	}
 
-	// Unlock map.
-	unlock()
+		// Perform emoji load operation.
+		emoji, err = processing.Load(ctx)
+		if err != nil {
+			err = gtserror.Newf("error loading emoji %s: %w", shortcodeDomain, err)
 
-	// Perform emoji load operation.
-	emoji, err = processing.Load(ctx)
-	if err != nil {
-		err = gtserror.Newf("error loading emoji %s: %w", shortcodeDomain, err)
-
-		// TODO: in time we should return checkable flags by gtserror.Is___()
-		// which can determine if loading error should allow remaining placeholder.
+			// TODO: in time we should return checkable flags by gtserror.Is___()
+			// which can determine if loading error should allow remaining placeholder.
+		}
 	}
 
 	return
@@ -364,7 +398,7 @@ func (d *Dereferencer) fetchEmojis(
 				URI:                  &placeholder.URI,
 				ImageRemoteURL:       &placeholder.ImageRemoteURL,
 				ImageStaticRemoteURL: &placeholder.ImageStaticRemoteURL,
-			}, force)
+			}, force, true)
 			if err != nil {
 				log.Errorf(ctx, "error refreshing emoji: %v", err)
 
@@ -396,6 +430,7 @@ func (d *Dereferencer) fetchEmojis(
 				ImageStaticRemoteURL: &placeholder.ImageStaticRemoteURL,
 			},
 			false,
+			true,
 		)
 		if err != nil {
 			if emoji == nil {
