@@ -18,19 +18,30 @@
 package user
 
 import (
-	"github.com/superseriousbusiness/gotosocial/internal/email"
-	"github.com/superseriousbusiness/gotosocial/internal/state"
+	"code.superseriousbusiness.org/gotosocial/internal/email"
+	"code.superseriousbusiness.org/gotosocial/internal/oauth"
+	"code.superseriousbusiness.org/gotosocial/internal/state"
+	"code.superseriousbusiness.org/gotosocial/internal/typeutils"
 )
 
 type Processor struct {
 	state       *state.State
+	converter   *typeutils.Converter
+	oauthServer oauth.Server
 	emailSender email.Sender
 }
 
-// New returns a new user processor
-func New(state *state.State, emailSender email.Sender) Processor {
+// New returns a new user processor.
+func New(
+	state *state.State,
+	converter *typeutils.Converter,
+	oauthServer oauth.Server,
+	emailSender email.Sender,
+) Processor {
 	return Processor{
 		state:       state,
+		converter:   converter,
+		oauthServer: oauthServer,
 		emailSender: emailSender,
 	}
 }
