@@ -31,7 +31,6 @@ import (
 	"code.superseriousbusiness.org/gotosocial/internal/processing/media"
 	"code.superseriousbusiness.org/gotosocial/internal/state"
 	"code.superseriousbusiness.org/gotosocial/internal/typeutils"
-	"code.superseriousbusiness.org/gotosocial/internal/util"
 )
 
 // util provides util functions used by both
@@ -285,247 +284,6 @@ func (u *utils) redirectFollowers(
 	return true
 }
 
-func (u *utils) incrementStatusesCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-	status *gtsmodel.Status,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update status meta for account.
-	*account.Stats.StatusesCount++
-	account.Stats.LastStatusAt = status.CreatedAt
-
-	// Update details in the database for stats.
-	if err := u.state.DB.UpdateAccountStats(ctx,
-		account.Stats,
-		"statuses_count",
-		"last_status_at",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
-func (u *utils) decrementStatusesCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-	status *gtsmodel.Status,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update status meta for account (safely checking for zero value).
-	*account.Stats.StatusesCount = util.Decr(*account.Stats.StatusesCount)
-
-	if !status.PinnedAt.IsZero() {
-		// Update status pinned count for account (safely checking for zero value).
-		*account.Stats.StatusesPinnedCount = util.Decr(*account.Stats.StatusesPinnedCount)
-	}
-
-	// Update details in the database for stats.
-	if err := u.state.DB.UpdateAccountStats(ctx,
-		account.Stats,
-		"statuses_count",
-		"statuses_pinned_count",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
-func (u *utils) incrementFollowersCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update stats by incrementing followers
-	// count by one and setting last posted.
-	*account.Stats.FollowersCount++
-	if err := u.state.DB.UpdateAccountStats(
-		ctx,
-		account.Stats,
-		"followers_count",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
-func (u *utils) decrementFollowersCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update stats by decrementing
-	// followers count by one.
-	//
-	// Clamp to 0 to avoid funny business.
-	*account.Stats.FollowersCount--
-	if *account.Stats.FollowersCount < 0 {
-		*account.Stats.FollowersCount = 0
-	}
-	if err := u.state.DB.UpdateAccountStats(
-		ctx,
-		account.Stats,
-		"followers_count",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
-func (u *utils) incrementFollowingCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update stats by incrementing
-	// followers count by one.
-	*account.Stats.FollowingCount++
-	if err := u.state.DB.UpdateAccountStats(
-		ctx,
-		account.Stats,
-		"following_count",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
-func (u *utils) decrementFollowingCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update stats by decrementing
-	// following count by one.
-	//
-	// Clamp to 0 to avoid funny business.
-	*account.Stats.FollowingCount--
-	if *account.Stats.FollowingCount < 0 {
-		*account.Stats.FollowingCount = 0
-	}
-	if err := u.state.DB.UpdateAccountStats(
-		ctx,
-		account.Stats,
-		"following_count",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
-func (u *utils) incrementFollowRequestsCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update stats by incrementing
-	// follow requests count by one.
-	*account.Stats.FollowRequestsCount++
-	if err := u.state.DB.UpdateAccountStats(
-		ctx,
-		account.Stats,
-		"follow_requests_count",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
-func (u *utils) decrementFollowRequestsCount(
-	ctx context.Context,
-	account *gtsmodel.Account,
-) error {
-	// Lock on this account since we're changing stats.
-	unlock := u.state.ProcessingLocks.Lock(account.URI)
-	defer unlock()
-
-	// Ensure account stats are populated.
-	if err := u.state.DB.PopulateAccountStats(ctx, account); err != nil {
-		return gtserror.Newf("db error getting account stats: %w", err)
-	}
-
-	// Update stats by decrementing
-	// follow requests count by one.
-	//
-	// Clamp to 0 to avoid funny business.
-	*account.Stats.FollowRequestsCount--
-	if *account.Stats.FollowRequestsCount < 0 {
-		*account.Stats.FollowRequestsCount = 0
-	}
-	if err := u.state.DB.UpdateAccountStats(
-		ctx,
-		account.Stats,
-		"follow_requests_count",
-	); err != nil {
-		return gtserror.Newf("db error updating account stats: %w", err)
-	}
-
-	return nil
-}
-
 // impoliteFaveRequest stores an interaction request
 // for the given fave, and notifies the interactee.
 //
