@@ -17,6 +17,8 @@
 
 package util
 
+import "unsafe"
+
 // EqualPtrs returns whether the values contained within two comparable ptr types are equal.
 func EqualPtrs[T comparable](t1, t2 *T) bool {
 	switch {
@@ -34,10 +36,33 @@ func Ptr[T any](t T) *T {
 	return &t
 }
 
-// PtrValueOr returns either value of ptr, or default.
-func PtrValueOr[T any](t *T, _default T) T {
+// PtrIf returns ptr value only if 't' non-zero.
+func PtrIf[T comparable](t T) *T {
+	var z T
+	if t == z {
+		return nil
+	}
+	return &t
+}
+
+// PtrOrZero returns either value of ptr, or zero.
+func PtrOrZero[T any](t *T) T {
+	if t == nil {
+		var z T
+		return z
+	}
+	return *t
+}
+
+// PtrOrValue returns either contained value of ptr, or 'value'.
+func PtrOrValue[T any](t *T, value T) T {
 	if t != nil {
 		return *t
 	}
-	return _default
+	return value
+}
+
+func IsNil(i interface{}) bool {
+	type eface struct{ _, data unsafe.Pointer }
+	return (*eface)(unsafe.Pointer(&i)).data == nil
 }
