@@ -1,8 +1,10 @@
 package structr
 
 import (
-	"sync"
+	"os"
 	"unsafe"
+
+	"codeberg.org/gruf/go-mempool"
 )
 
 type indexed_item struct {
@@ -10,38 +12,41 @@ type indexed_item struct {
 	// is stored in a main list.
 	elem list_elem
 
+	// cached data with type.
+	data interface{}
+
 	// indexed stores the indices
 	// this item is stored under.
 	indexed []*index_entry
-
-	// cached data with type.
-	data interface{}
 }
 
-var indexed_item_pool sync.Pool
+var indexed_item_pool mempool.UnsafePool
 
 // new_indexed_item returns a new prepared indexed_item.
 func new_indexed_item() *indexed_item {
-	v := indexed_item_pool.Get()
-	if v == nil {
-		v = new(indexed_item)
+	if ptr := indexed_item_pool.Get(); ptr != nil {
+		return (*indexed_item)(ptr)
 	}
-	item := v.(*indexed_item)
-	ptr := unsafe.Pointer(item)
-	item.elem.data = ptr
+	item := new(indexed_item)
+	item.elem.data = unsafe.Pointer(item)
 	return item
 }
 
 // free_indexed_item releases the indexed_item.
 func free_indexed_item(item *indexed_item) {
-	item.elem.data = nil
-	item.indexed = item.indexed[:0]
+	if len(item.indexed) > 0 ||
+		item.elem.next != nil ||
+		item.elem.prev != nil {
+		msg := assert("item not in use")
+		os.Stderr.WriteString(msg + "\n")
+		return
+	}
 	item.data = nil
-	indexed_item_pool.Put(item)
+	ptr := unsafe.Pointer(item)
+	indexed_item_pool.Put(ptr)
 }
 
 // drop_index will drop the given index entry from item's indexed.
-// note this also handles freeing the index_entry memory (e.g. to pool)
 func (i *indexed_item) drop_index(entry *index_entry) {
 	for x := 0; x < len(i.indexed); x++ {
 		if i.indexed[x] != entry {
@@ -51,8 +56,9 @@ func (i *indexed_item) drop_index(entry *index_entry) {
 			continue
 		}
 
-		// Move all index entries down + reslice.
-		copy(i.indexed[x:], i.indexed[x+1:])
+		// Reslice index entries minus 'x'.
+		_ = copy(i.indexed[x:], i.indexed[x+1:])
+		i.indexed[len(i.indexed)-1] = nil
 		i.indexed = i.indexed[:len(i.indexed)-1]
 		break
 	}
